==> haskell-swagger2-2.3.1.1-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-swagger2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: swagger2
version: 2.3.1.1
id: swagger2-2.3.1.1-7Dz18e4qxJJA6ehZPHcKcm
key: swagger2-2.3.1.1-7Dz18e4qxJJA6ehZPHcKcm
license: BSD-3-Clause
copyright: (c) 2015-2016, GetShopTV
maintainer: nickolay@getshoptv.com
author: Nickolay Kudasov
homepage: https://github.com/GetShopTV/swagger2
synopsis: Swagger 2.0 data model
description:
    This library is intended to be used for decoding and encoding Swagger 2.0 API
    specifications as well as manipulating them.
    .
    The original Swagger 2.0 specification is available at http://swagger.io/specification/.
category: Web, Swagger
abi: c747e03776d58b774d8d5b8e22b7f597
exposed: True
exposed-modules:
    Data.Swagger Data.Swagger.Declare Data.Swagger.Internal
    Data.Swagger.Internal.AesonUtils Data.Swagger.Internal.ParamSchema
    Data.Swagger.Internal.Schema
    Data.Swagger.Internal.Schema.Validation
    Data.Swagger.Internal.TypeShape Data.Swagger.Internal.Utils
    Data.Swagger.Lens Data.Swagger.Operation Data.Swagger.ParamSchema
    Data.Swagger.Schema Data.Swagger.Schema.Generator
    Data.Swagger.Schema.Validation Data.Swagger.SchemaOptions
import-dirs: /usr/lib/ghc-8.6.4/site-local/swagger2-2.3.1.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/swagger2-2.3.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/swagger2-2.3.1.1
hs-libraries: HSswagger2-2.3.1.1-7Dz18e4qxJJA6ehZPHcKcm
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6
    aeson-1.4.2.0-DX8Ttq0Dq5cG6DT1joU4wl base-4.12.0.0
    base-compat-batteries-0.10.5-FV04YR1JB9h4zMEjXyKDtx
    bytestring-0.10.8.2 containers-0.6.0.1
    cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx
    generics-sop-0.4.0.1-50QtUhSPhiXGrcY9j3QNt9
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    http-media-0.7.1.3-7B92MKhk7rgJnZ6fbAqMYu
    insert-ordered-containers-0.2.1.0-AvSLGeYSHV7D0buivlnUWo
    lens-4.17-Ho2XjZ15d8i5p2rFPy4ulk mtl-2.2.2
    network-2.8.0.0-65TWeU8omLsDYfm0yvOQxG
    scientific-0.3.6.2-BVEhLkswVxa6jxFFJ9XwaR template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    transformers-compat-0.6.2-IT1pgM4Lod5B9rerVXsOk7
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    uuid-types-1.0.3-1r1IBIU9fBZK1eE2MZEQJb
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-swagger2/html/swagger2.haddock
haddock-html: /usr/share/doc/haskell-swagger2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-swagger2-2.3.1.1-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-swagger2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: swagger2
version: 2.3.1.1
id: swagger2-2.3.1.1-IhonpYom34YCs6JWOiLrwq
key: swagger2-2.3.1.1-IhonpYom34YCs6JWOiLrwq
license: BSD-3-Clause
copyright: (c) 2015-2016, GetShopTV
maintainer: nickolay@getshoptv.com
author: Nickolay Kudasov
homepage: https://github.com/GetShopTV/swagger2
synopsis: Swagger 2.0 data model
description:
    This library is intended to be used for decoding and encoding Swagger 2.0 API
    specifications as well as manipulating them.
    .
    The original Swagger 2.0 specification is available at http://swagger.io/specification/.
category: Web, Swagger
abi: 3d27980bd489c9497f9bb83782382e08
exposed: True
exposed-modules:
    Data.Swagger Data.Swagger.Declare Data.Swagger.Internal
    Data.Swagger.Internal.AesonUtils Data.Swagger.Internal.ParamSchema
    Data.Swagger.Internal.Schema
    Data.Swagger.Internal.Schema.Validation
    Data.Swagger.Internal.TypeShape Data.Swagger.Internal.Utils
    Data.Swagger.Lens Data.Swagger.Operation Data.Swagger.ParamSchema
    Data.Swagger.Schema Data.Swagger.Schema.Generator
    Data.Swagger.Schema.Validation Data.Swagger.SchemaOptions
import-dirs: /usr/lib/ghc-8.6.4/site-local/swagger2-2.3.1.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/swagger2-2.3.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/swagger2-2.3.1.1
hs-libraries: HSswagger2-2.3.1.1-IhonpYom34YCs6JWOiLrwq
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6
    aeson-1.4.2.0-QHLwhPMHVB663aXnGqoMq base-4.12.0.0
    base-compat-batteries-0.10.5-K6GIixJOgdMLVWYWPQ6fxr
    bytestring-0.10.8.2 containers-0.6.0.1
    cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx
    generics-sop-0.4.0.1-50QtUhSPhiXGrcY9j3QNt9
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    http-media-0.7.1.3-7B92MKhk7rgJnZ6fbAqMYu
    insert-ordered-containers-0.2.1.0-KqaX1tWMwu2DsFU1KGV5kc
    lens-4.17-F6A8Oj3hNsE3ZcSNZZdK9Q mtl-2.2.2
    network-2.8.0.0-58b93NZ1Nmb3T9F5Ys3Y7W
    scientific-0.3.6.2-BVEhLkswVxa6jxFFJ9XwaR template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    transformers-compat-0.6.2-IT1pgM4Lod5B9rerVXsOk7
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    uuid-types-1.0.3-1r1IBIU9fBZK1eE2MZEQJb
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-swagger2/html/swagger2.haddock
haddock-html: /usr/share/doc/haskell-swagger2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
